diff libpurple/notify.h @ 32366:99ca503ea087

Rename purple_notify_user_info_add_pair to purple_notify_user_info_add_pair_html, to be more explicit so hopefully people don't pass this non-html in the future.
author Mark Doliner <mark@kingant.net>
date Mon, 22 Aug 2011 02:23:28 +0000
parents 489b20ff1c72
children 6283c0f2b02f
line wrap: on
line diff
--- a/libpurple/notify.h	Mon Aug 22 02:11:36 2011 +0000
+++ b/libpurple/notify.h	Mon Aug 22 02:23:28 2011 +0000
@@ -480,16 +480,10 @@
  *                   the UI should treat label as independent and not
  *                   include a colon if it would otherwise.
  */
-/*
- * TODO: In 3.0.0 this function should be renamed to
- *       purple_notify_user_info_add_pair_html().  And optionally
- *       purple_notify_user_info_add_pair_plaintext() could be renamed to
- *       purple_notify_user_info_add_pair().
- */
-void purple_notify_user_info_add_pair(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
+void purple_notify_user_info_add_pair_html(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
 
 /**
  * Like purple_notify_user_info_add_pair, but value should be plaintext
  * and will be escaped using g_markup_escape_text().
  */
 void purple_notify_user_info_add_pair_plaintext(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
@@ -530,7 +524,8 @@
  *
  * If added to a PurpleNotifyUserInfo object, this should not be free()'d,
  * as PurpleNotifyUserInfo will do so when destroyed.
- * purple_notify_user_info_add_pair() and
+ * purple_notify_user_info_add_pair_html(),
+ * purple_notify_user_info_add_pair_plaintext() and
  * purple_notify_user_info_prepend_pair() are convenience methods for
  * creating entries and adding them to a PurpleNotifyUserInfo.
  *
@@ -480,16 +480,10 @@
 
 /**
- * Like purple_notify_user_info_add_pair, but value should be plaintext
+ * Like purple_notify_user_info_add_pair_html, but value should be plaintext
  * and will be escaped using g_markup_escape_text().
  */